import bpy
import math

""" Adds copy transforms to a metarig, targeting a rigify rig called 'adjuster'.
    Select metarig, enter edit mode, select the target bones, run script.
"""

def get_edit_info(seq, target):
    """ While in edit mode, scans all bones in an editbone sequence 
        and returns a list of the target attribute e.g. head, bone length, etc.
    """
    attribute_list = []
    for i in range(len(seq)):
        attribute_list.append(getattr(seq[i], target))
    return attribute_list

rig = bpy.context.scene.objects.active
rigify = bpy.context.scene.objects['adjuster']

bone_names = get_edit_info(bpy.context.selected_editable_bones, 'name')

#Add IK constraints to each bone that will copy the BVH
bpy.ops.object.mode_set(mode = 'POSE')

for i in range(len(bone_names)):
    pose_bone = bpy.data.objects[rig.name].pose.bones[bone_names[i]]
    pose_bone.constraints.new('COPY_TRANSFORMS')
    pose_bone.constraints[0].target = rigify
    pose_bone.constraints[0].subtarget = 'ORG-' + bone_names[i]
    pose_bone.constraints[0].target_space = 'LOCAL'
    pose_bone.constraints[0].owner_space = 'LOCAL'
